@@ -7,5 +7,5 @@ from .fcnn import *
 from .fnet import *
 from .mixer import *
 from .linear import *
-from .protocol import *
+from .pool_former import *
 from .transformer import *
